function [C] = DFT_Covariance(k1, k2, N, K, H)

% Inputs:
% - k1:     Spectrum sample parameter 1;
% - k2:    	Spectrum sample parameter 2;
% - N:   	Sample data length;
% - K:    	Transform length;
% - H:      Coefficients of the apodization function.
%
% Outputs:
% - C:      Noise covariance matrix of DFT samples.


%% PROCESSING
% Initialization
C = 0;

% Loop over window coefficients
for h1 = 0:length(H)-1
    for h2 = 0:length(H)-1
        
        C  = C + H(1 + h1) * H(1 + h2) / 4 * (DFT(k1 - k2 + (+h1 + h2) * K/N, N, K) + ...
                                              DFT(k1 - k2 + (+h1 - h2) * K/N, N, K) + ...
                                              DFT(k1 - k2 + (-h1 - h2) * K/N, N, K) + ...
                                              DFT(k1 - k2 + (-h1 + h2) * K/N, N, K) ) ;
        
    end
end