function [dP] = dEnergy_Spectrum(k, N, K, H)

% Inputs:
% - k:     	Spectrum sample parameter;
% - N:   	Sample data length;
% - K:    	Transform length;
% - H:      Coefficients of the apodization function.
%
% Outputs:
% - dP:     Derivative of the normalized energy spectrum of a sinusoïdal signal in a noiseless case.


%% PROCESSING
% Initialization
dP = 0;

% Loop over window coefficients
for h1 = 0:length(H)-1
    for h2 = 0:length(H)-1
        
        dP = dP + H(1 + h1)/2 *     (dDFT(k + h1 * K/N, N, K) + dDFT(k - h1 * K/N, N, K)) * ...
                  H(1 + h2)/2 * conj( DFT(k + h2 * K/N, N, K) +  DFT(k - h2 * K/N, N, K)) + ...
                  H(1 + h1)/2 *     ( DFT(k + h1 * K/N, N, K) +  DFT(k - h1 * K/N, N, K)) * ...
                  H(1 + h2)/2 * conj(dDFT(k + h2 * K/N, N, K) + dDFT(k - h2 * K/N, N, K)) ;
        
    end
end

% Outputs
dP = real(dP);